@@ -10,7 +10,8 @@ team = mcolors.ListedColormap([colors['OPPOSITION'], colors['CONTESTED'], colors
 analyst = mcolors.ListedColormap([colors['OPPOSITION'], colors['CONTESTED'], colors['TEAM']])
 
 
-excluded_vars = {'colormaps', 'colors', 'plt', 'mcolors', 'excluded_vars', 'var', 'cmap', 'register_cmaps'}
+excluded_vars = {'colormaps', 'colors', 'plt', 'mcolors', 'excluded_vars', 
+                 'colormap_names', 'color_names', 'var', 'cmap', 'register_cmaps'}
 
 colormaps = {}
 for var in dir():
